@@ -25,6 +25,9 @@
 
 #include "box_data_manyrecords.h"
 #include <glom/utility_widgets/layoutwidgetbase.h>
+#include <gtkmm/alignment.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/label.h>
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/button.h>
@@ -77,7 +80,14 @@ public:
   type_signal_portal_record_changed signal_portal_record_changed();
     
   bool get_has_suitable_record_to_view_details() const;
-  void get_suitable_table_to_view_details(Glib::ustring& table_name, sharedptr<const UsesRelationship>& relationship) const;
+
+  /** Discover what record to show, in what table, when clicking on a related record.
+   * This record will not necessarily just be the directly related record.
+   *
+   * @param primary_key_value Identifies the related record that has been clicked.
+   * @param table_name The table that should be shown.
+   * @param table_primary_key_value Identifies the record in that table that should be shown.
+   */
   void get_suitable_record_to_view_details(const Gnome::Gda::Value& primary_key_value, Glib::ustring& table_name, Gnome::Gda::Value& table_primary_key_value) const;
 
 protected:
